==> gsad_22.4.1.orig.tar.gz: gsad-22.4.1/changelog/22.4.0.md <==
# Changelog

All notable changes to this project will be documented in this file.

## [22.4.0] - 2022-07-22

## Removed
* Removing the OSP scanners in gsad [#13] [aa1a85dcb](https://github.com/greenbone/gsad/commit/aa1a85dcb)

## Changed
* Remove clang from docker image, minor cleanup [879aa14cb](https://github.com/greenbone/gsad/commit/879aa14cb)
* Set runtime directory and mode for systemd service file [3a6b34f9d](https://github.com/greenbone/gsad/commit/3a6b34f9d)
* Add RuntimeDirectory=gsad to systemd service file #56 [3319850e6](https://github.com/greenbone/gsad/commit/3319850e6)
* Remove Group directive from service file #55 [2d299035e](https://github.com/greenbone/gsad/commit/2d299035e)
* Don't create runtime directory with make install #54 [ab6aa4c38](https://github.com/greenbone/gsad/commit/ab6aa4c38)
* Add status 503 case to set_http_status_from_entity [42d4b4e58](https://github.com/greenbone/gsad/commit/42d4b4e58)
* Change GVM_RUN_DIR to GSAD_RUN_DIR, GVMD_RUN_DIR [3a27a8543](https://github.com/greenbone/gsad/commit/3a27a8543)
* Use full path GSAD_PID_PATH for PID files [14bf44900](https://github.com/greenbone/gsad/commit/14bf44900)

## Bug Fixes
* Changed the order of the parameters of MHD_start_daemon (...) [325560697](https://github.com/greenbone/gsad/commit/325560697)
* Use correct PID path in service file [fbaa81646](https://github.com/greenbone/gsad/commit/fbaa81646)
* severity field within gmp_authenticate_info_opts_t got deleted [50a9326b1](https://github.com/greenbone/gsad/commit/50a9326b1)

[22.4.0]: https://github.com/greenbone/gsad/compare/v21.4.4...v22.4.0

==> gsad_22.8.0.orig.tar.gz: gsad-22.8.0/changelog/v22.4.md <==
# Changelog

All notable changes to this project will be documented in this file.

## [22.4] - 2022-07-19

## Removed
* Removing the OSP scanners in gsad [#13] [aa1a85dcb](https://github.com/greenbone/gsad/commit/aa1a85dcb)

## Changed
* Remove clang from docker image, minor cleanup [879aa14cb](https://github.com/greenbone/gsad/commit/879aa14cb)
* Set runtime directory and mode for systemd service file [3a6b34f9d](https://github.com/greenbone/gsad/commit/3a6b34f9d)
* Add RuntimeDirectory=gsad to systemd service file #56 [3319850e6](https://github.com/greenbone/gsad/commit/3319850e6)
* Remove Group directive from service file #55 [2d299035e](https://github.com/greenbone/gsad/commit/2d299035e)
* Don't create runtime directory with make install #54 [ab6aa4c38](https://github.com/greenbone/gsad/commit/ab6aa4c38)
* Add status 503 case to set_http_status_from_entity [42d4b4e58](https://github.com/greenbone/gsad/commit/42d4b4e58)
* Change GVM_RUN_DIR to GSAD_RUN_DIR, GVMD_RUN_DIR [3a27a8543](https://github.com/greenbone/gsad/commit/3a27a8543)
* Use full path GSAD_PID_PATH for PID files [14bf44900](https://github.com/greenbone/gsad/commit/14bf44900)

## Bug Fixes
* Changed the order of the parameters of MHD_start_daemon (...) [325560697](https://github.com/greenbone/gsad/commit/325560697)
* Use correct PID path in service file [fbaa81646](https://github.com/greenbone/gsad/commit/fbaa81646)
* severity field within gmp_authenticate_info_opts_t got deleted [50a9326b1](https://github.com/greenbone/gsad/commit/50a9326b1)

[22.4]: https://github.com/greenbone/gsad/compare/22.4...22.4
